@@ -48,6 +48,7 @@ bool gx_jack_init( const string *optvar )
 	client_name = "guitarix_amp";
 	client_insert_name = "guitarix_fx";
 	client_instance = "guitarix";
+	int jack_is_fresh = 0;
 
 	AVOIDDENORMALS;
 
@@ -96,6 +97,7 @@ bool gx_jack_init( const string *optvar )
 				               string("I really tried to get jack up and running, sorry ... "));
 				return false;
 			}
+			jack_is_fresh = 1;
 		}
 
 		else   // we give up
@@ -148,7 +150,7 @@ bool gx_jack_init( const string *optvar )
 	 string window_name = "guitarix";
 		gtk_window_set_title (GTK_WINDOW (gx_gui::fWindow), window_name.c_str());
 	}
-
+    if(jack_is_fresh) sleep(8);
 	return true;
 }
 
@@ -260,9 +262,20 @@ void gx_jack_callbacks_and_activate()
 	}
 }
 
+static gboolean gx_engine_restart(gpointer data)
+{
+	usleep(5);
+	checky = kEngineOn;
+	return false;
+}
+
 //----- connect ports if we know them
 void gx_jack_init_port_connection(const string* optvar)
 {
+    // set engine off for one GTK thread cycle to avoid Xrun at startup
+    gx_gui::g_threads[4] = g_idle_add_full(G_PRIORITY_HIGH_IDLE+20,gx_engine_restart,NULL,NULL);
+    checky = kEngineOff;
+
 	// set autoconnect capture to user capture port
 	if (!optvar[JACK_INP].empty())
 	{
@@ -333,6 +346,7 @@ void gx_jack_init_port_connection(const string* optvar)
 	if (!ifound || !ofound) {
 		jack_connect(client_insert, jack_port_name(output_ports[0]), (client_insert_name+":in_0").c_str());
 	}
+
 }
 
 //----- pop up a dialog for starting jack
@@ -532,16 +546,16 @@ void gx_set_jack_buffer_size(GtkCheckMenuItem* menuitem, gpointer arg)
 	// ----- if check button triggered menually
 
 	// let's avoid triggering the jack server on "inactive"
-	if (gtk_check_menu_item_get_active(menuitem) == false)
+	if (gtk_check_menu_item_get_active(menuitem) == false) {
 		return;
-
+	}
 	// requested latency
 	jack_nframes_t buf_size = (jack_nframes_t)GPOINTER_TO_INT(arg);
 
 	// if the actual buffer size is the same, no need further action
-	if (buf_size == jack_get_buffer_size(client))
+	if (buf_size == jack_get_buffer_size(client)) {
 		return;
-
+	}
 
 	// first time useage warning
 	GxJackLatencyChange change_latency = kChangeLatency;
@@ -551,38 +565,17 @@ void gx_set_jack_buffer_size(GtkCheckMenuItem* menuitem, gpointer arg)
 		change_latency = (GxJackLatencyChange)gx_gui::gx_wait_latency_warn();
 
 	// let's see
-	if (change_latency == kChangeLatency)
-	{
-		int jcio = 0;
-		if (conv.is_runnable())
-		{
-			jcio = 1;
-			gx_jconv::GxJConvSettings::checkbutton7 = 0;
-			gx_jconv::checkbox7 = 0.0;
-			gx_gui::gx_start_stop_jconv(NULL, NULL);
-		}
-
+	if (change_latency == kChangeLatency) {
 		// let's resize the buffer
 		if (jack_set_buffer_size (client, buf_size) != 0)
 			gx_print_warning("Setting Jack Buffer Size",
 			                 "Could not change latency");
-
-		if (jcio == 1)
-		{
-			jcio = 0;
-			gx_jconv::GxJConvSettings::checkbutton7 = 1;
-			gx_jconv::checkbox7 = 1.0;
-			gx_gui::gx_start_stop_jconv(NULL, NULL);
-		}
-	}
-	else // restore latency status
-	{
+	} else { // restore latency status
 		// refresh latency check menu
 		gx_gui::GxMainInterface* gui = gx_gui::GxMainInterface::instance();
 		GtkWidget* wd = gui->getJackLatencyItem(jack_bs);
 		if (wd) gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(wd), TRUE);
 	}
-
 	gx_print_info("Jack Buffer Size",
 	              string("latency is ") +
 	              gx_i2a(jack_get_buffer_size(client)));
@@ -654,7 +647,7 @@ int gx_jack_xrun_callback (void* arg)
 //---- jack buffer size change callback
 int gx_jack_buffersize_callback (jack_nframes_t nframes,void* arg)
 {
-	GxEngineState estate = (GxEngineState)checky;
+	GxEngineState estate = checky;
 
 	// turn off engine
 	// Note: simply changing checky is enough to "stop" processing
@@ -666,7 +659,7 @@ int gx_jack_buffersize_callback (jack_nframes_t nframes,void* arg)
 	// immediately during the jack_processing of jack cycles.
 
 	if (estate != kEngineOff)
-		checky = (float)kEngineOff;
+		checky = kEngineOff;
 
 	jack_bs = nframes;
 
@@ -692,8 +685,20 @@ int gx_jack_buffersize_callback (jack_nframes_t nframes,void* arg)
 	result = new float[jack_bs+46];
 	(void)memset(result, 0, sizeof(float)*jack_bs+46);
 
+	gx_gui::GxMainInterface::instance()->set_waveview_buffer();
+	if (cab_conv.is_runnable()) {
+		cab_conv.set_not_runnable();
+		Glib::signal_idle().connect(
+			sigc::bind_return(sigc::ptr_fun(gx_gui::cab_conv_restart), false));
+	}
+	if (conv.is_runnable()) {
+		conv.set_not_runnable();
+		Glib::signal_idle().connect(
+			sigc::bind_return(sigc::ptr_fun(gx_gui::conv_restart), false));
+	}
+
 	// restore previous state
-	checky = (float)estate;
+	checky = estate;
 	// return 0 to jack
 	return 0;
 
