@@ -532,6 +532,10 @@ string param_group(string id, bool nowarn)
  ** Parameter
  */
 
+Parameter::~Parameter()
+{
+}
+
 static int get_upper(const char **vn)
 {
 	for (int n = 0; ; n++) {
@@ -615,6 +619,11 @@ void FloatParameter::setJSON_value()
 	set(json_value);
 }
 
+void FloatParameter::convert_from_range(float low, float up)
+{
+	json_value = lower + (json_value - low) / (up - low) * (upper - lower);
+}
+
 bool FloatParameter::hasRange() const
 {
 	return true;
@@ -665,7 +674,7 @@ void FloatEnumParameter::readJSON_value(gx_system::JsonParser& jp)
 		return;
 	}
 	jp.check_expect(gx_system::JsonParser::value_string);
-	int up = round(upper);
+	int up = int(round(upper));
 	int n = 0;
 	for (; n <= up; n++) {
 		if (jp.current_value() == value_names[n]) {
