@@ -120,7 +120,7 @@ bool gx_modify_preset(const char* presname, const char* newname=0, bool remove=f
 				jw.write(jp.current_value());
 				gx_gui::parameter_map.set_init_values();
 				bool has_midi;
-				read_preset(jp, &has_midi);
+				read_preset(jp, &has_midi, major, minor);
 				write_preset(jw,false,has_midi);
 			} else if (jp.current_value() == presname) {
 				found = true;
@@ -194,8 +194,9 @@ static bool gx_build_preset_list()
 			// ---- how many did we get ?
 			gx_print_info("Preset List Building",
 			                 gx_i2a(plist.size()) + string(" presets found"));
-			if (!samevers) {
+			if (!samevers && gx_preset_file.is_standard()) {
 				gx_modify_preset(0,0,false,true);
+				gx_system::recallState(gx_user_dir + gx_jack::client_instance + "_rc"); //FIXME
 			}
 			return true;
 		} catch (gx_system::JsonException& e) {
@@ -234,7 +235,7 @@ void gx_add_single_preset_menu_item(const string& presname,
 	// index for keyboard shortcut (can take any list)
     vector<GtkMenuItem*>::iterator its;
     int pos = 0;
-    for (its = pm_list[lindex].begin() ; its < pm_list[lindex].end(); its++ )
+    for (its = pm_list[lindex].begin() ; its != pm_list[lindex].end(); its++ )
     {
         pos++;
     }
@@ -282,7 +283,7 @@ int gx_get_single_preset_menu_pos(const string& presname, const gint lindex)
 {
     vector<string>::iterator its;
     int pos = 0;
-    for (its = plist.begin() ; its < plist.end(); its++ )
+    for (its = plist.begin() ; its != plist.end(); its++ )
     {
         pos++;
         if( presname == *its)
@@ -297,7 +298,7 @@ GtkMenuItem* const gx_get_preset_item_from_name(int lindex, const string& name)
     vector<string>::iterator its;
     vector<GtkMenuItem*>::iterator it = pm_list[lindex].begin();
     int pos = 0;
-    for (its = plist.begin() ; its < plist.end(); its++ )
+    for (its = plist.begin() ; its != plist.end(); its++ )
     {
         pos++;
         if( name == *its)
@@ -323,7 +324,7 @@ void gx_refresh_preset_menus()
 		gx_build_preset_list();
     }
     vector<string>::iterator its;
-    for (its = plist.begin() ; its < plist.end(); its++) {
+    for (its = plist.begin() ; its != plist.end(); its++) {
 	    gx_add_preset_to_menus(*its);
     }
 }
@@ -368,7 +369,7 @@ void gx_next_preset(GtkWidget* item, gpointer arg)
 	{
 		GtkMenuItem* const itemi =
 			gx_get_preset_item_from_name(LOAD_PRESET_LIST, gx_current_preset);
-        for (it = pm_list[LOAD_PRESET_LIST].begin() ; it < pm_list[LOAD_PRESET_LIST].end(); it++ )
+        for (it = pm_list[LOAD_PRESET_LIST].begin() ; it != pm_list[LOAD_PRESET_LIST].end(); it++ )
         {
             if( itemi == *it)
                 break;
@@ -400,7 +401,7 @@ void gx_previous_preset(GtkWidget* item, gpointer arg)
 	{
 		GtkMenuItem* const itemi =
 			gx_get_preset_item_from_name(LOAD_PRESET_LIST, gx_current_preset);
-        for (it = pm_list[LOAD_PRESET_LIST].begin() ; it < pm_list[LOAD_PRESET_LIST].end(); it++ )
+        for (it = pm_list[LOAD_PRESET_LIST].begin() ; it != pm_list[LOAD_PRESET_LIST].end(); it++ )
         {
             if( itemi == *it)
                 break;
@@ -531,14 +532,15 @@ bool gx_load_preset_from_file(const char* presname)
 
 	try {
 		jp.next(JsonParser::begin_array);
-		readHeader(jp);
+		int major, minor;
+		readHeader(jp, &major, &minor);
 
 		bool found = false;
 		while (jp.peek() != JsonParser::end_array) {
 			jp.next(JsonParser::value_string);
 			if (jp.current_value() == presname) {
 				found = true;
-				read_preset(jp);
+				read_preset(jp, 0, major, minor);
 				return true;
 			} else {
 				jp.skip_object();
@@ -612,10 +614,9 @@ static gboolean gx_convolver_restart(gpointer data)
     while (gx_engine::conv.is_runnable()) gx_engine::conv.checkstate();
     gx_jconv::GxJConvSettings* jcset = gx_jconv::GxJConvSettings::instance();
     bool rc = gx_engine::conv.configure(
-    gx_jack::jack_bs, gx_jack::jack_sr, jcset->getIRDir()+"/"+jcset->getIRFile(),
-        jcset->getGain(), jcset->getlGain(), jcset->getDelay(), jcset->getlDelay(),
-        jcset->getOffset(), jcset->getLength(), jcset->getMem(), jcset->getBufferSize());
-
+	    gx_jack::jack_bs, gx_jack::jack_sr, jcset->getFullIRPath(),
+	    jcset->getGain(), jcset->getGain(), jcset->getDelay(), jcset->getDelay(),
+	    jcset->getOffset(), jcset->getLength(), 0, 0, jcset->getGainline());
     if (!rc || !gx_engine::conv.start()) {
         gx_jconv::GxJConvSettings::checkbutton7 = 0;
     }
@@ -628,7 +629,7 @@ static gboolean gx_rename_main_widget(gpointer data)
     string title = string("guitarix ") + gx_current_preset;
 	gtk_window_set_title (GTK_WINDOW (gx_gui::fWindow), title.c_str());
 	// reload convolver settings widget
-	gx_jconv::gx_reload_jcgui();
+	//gx_jconv::gx_reload_jcgui();
     return false;
 }
 
@@ -646,7 +647,7 @@ void gx_load_preset (GtkMenuItem *menuitem, gpointer load_preset)
 	// retrieve preset name
     vector<GtkMenuItem*>::iterator it = pm_list[LOAD_PRESET_LIST].begin();
 	vector<string>::iterator its = plist.begin() ;;
-        for (it = pm_list[LOAD_PRESET_LIST].begin() ; it < pm_list[LOAD_PRESET_LIST].end(); it++ )
+        for (it = pm_list[LOAD_PRESET_LIST].begin() ; it != pm_list[LOAD_PRESET_LIST].end(); it++ )
         {
             if( menuitem == *it)
                 break;
@@ -673,6 +674,8 @@ void gx_load_preset (GtkMenuItem *menuitem, gpointer load_preset)
 
 	gx_current_preset = preset_name;
 
+	gx_jconv::gx_reload_jcgui();
+
 	/* do some GUI stuff*/
 	g_idle_add(gx_rename_main_widget,NULL);
 
@@ -814,7 +817,7 @@ void gx_save_oldpreset (GtkMenuItem *menuitem, gpointer arg)
 
         vector<GtkMenuItem*>::iterator it;
 
-         for (it = pm_list[SAVE_PRESET_LIST].begin() ; it < pm_list[LOAD_PRESET_LIST].end(); it++ ) {
+         for (it = pm_list[SAVE_PRESET_LIST].begin() ; it != pm_list[SAVE_PRESET_LIST].end(); it++ ) {
 	         if( menuitem == *it) {
 		         break;
 	         }
@@ -852,7 +855,7 @@ void gx_save_newpreset (GtkEntry* entry)
 	vector<string>::iterator its;
     vector<GtkMenuItem*>::iterator it = pm_list[SAVE_PRESET_LIST].begin();
 
-    for (its = plist.begin() ; its < plist.end(); its++ )
+    for (its = plist.begin() ; its != plist.end(); its++ )
     {
 		// found a match
 		if (presname == *its)
@@ -970,7 +973,7 @@ void gx_rename_preset_dialog (GtkMenuItem *menuitem, gpointer arg)
 {
     vector<string>::iterator its = plist.begin();
     vector<GtkMenuItem*>::iterator it = pm_list[RENAME_PRESET_LIST].begin();
-     for (it = pm_list[RENAME_PRESET_LIST].begin() ; it < pm_list[RENAME_PRESET_LIST].end(); it++ )
+     for (it = pm_list[RENAME_PRESET_LIST].begin() ; it != pm_list[RENAME_PRESET_LIST].end(); it++ )
         {
             if( menuitem == *it)
                 break;
