@@ -491,7 +491,23 @@ void write_preset(JsonWriter &w, bool write_midi, bool force_midi)
 	w.end_object(true);
 }
 
-void read_preset(JsonParser &jp, bool *has_midi)
+void fixup_parameters(int major, int minor)
+{
+	assert(gx_gui::parameter_map.hasId("jconv.wet_dry"));
+	if (major == majorversion && minor == minorversion) {
+		return;
+	}
+	if (major == 1 && minor < 2) {
+		if (gx_gui::parameter_map.hasId("jconv.wet_dry")) {
+			gx_gui::Parameter& p = gx_gui::parameter_map["jconv.wet_dry"];
+			if (p.isFloat()) {
+				p.getFloat().convert_from_range(-1,1);
+			}
+		}
+	}
+}
+
+void read_preset(JsonParser &jp, bool *has_midi, int major, int minor)
 {
 	gx_gui::paramlist plist;
 	if (has_midi) {
@@ -522,6 +538,7 @@ void read_preset(JsonParser &jp, bool *has_midi)
 	} while (jp.peek() == JsonParser::value_key);
 	jp.next(JsonParser::end_object);
 	gx_gui::controller_map.remove_controlled_parameters(plist, m);
+	fixup_parameters(major,minor);
 	for (gx_gui::paramlist::iterator i = plist.begin(); i != plist.end(); i++) {
 		(*i)->setJSON_value();
 	}
@@ -677,8 +694,8 @@ bool recallState( const string &filename )
 	try {
 		jp.next(JsonParser::begin_array);
 
-		int major;
-		readHeader(jp, &major);
+		int major, minor;
+		readHeader(jp, &major, &minor);
 		if (major != majorversion) {
 			if (major == 0) {
 				gx_print_info("recall settings", "loading converted state");
@@ -696,7 +713,7 @@ bool recallState( const string &filename )
 			if (jp.current_value() == "settings") {
 				read_parameters(jp, plist, false);
 			} else if (jp.current_value() == "current_preset") {
-				read_preset(jp);
+				read_preset(jp, 0, major, minor);
 			} else if (jp.current_value() == "midi_controller") {
 				gx_gui::controller_map.readJSON(jp, m);
 			} else if (jp.current_value() == "midi_ctrl_names") {
@@ -941,17 +958,24 @@ void gx_process_cmdline_options(int& argc, char**& argv, string* optvar)
 
 	// DEBUG options
 	string builder_dir;
+	string style_dir;
 	bool lterminal = false;
 	Glib::OptionGroup optgroup_debug(
 		"debug",
 		"\033[1;32mDebug options\033[0m",
 		"\033[1;32mDebug options\033[0m");
-	Glib::OptionEntry opt_debug;
-	opt_debug.set_short_name('B');
-	opt_debug.set_long_name("builder-dir");
-	opt_debug.set_description("directory from which .glade files are loaded");
-	opt_debug.set_arg_description("DIR");
-	optgroup_debug.add_entry_filename(opt_debug, builder_dir);
+	Glib::OptionEntry opt_builder_dir;
+	opt_builder_dir.set_short_name('B');
+	opt_builder_dir.set_long_name("builder-dir");
+	opt_builder_dir.set_description("directory from which .glade files are loaded");
+	opt_builder_dir.set_arg_description("DIR");
+	optgroup_debug.add_entry_filename(opt_builder_dir, builder_dir);
+	Glib::OptionEntry opt_style_dir;
+	opt_style_dir.set_short_name('S');
+	opt_style_dir.set_long_name("style-dir");
+	opt_style_dir.set_description("directory with skin style definitions (.rc files)");
+	opt_style_dir.set_arg_description("DIR");
+	optgroup_debug.add_entry_filename(opt_style_dir, style_dir);
 	Glib::OptionEntry opt_log_terminal;
 	opt_log_terminal.set_short_name('t');
 	opt_log_terminal.set_long_name("log-terminal");
@@ -1042,6 +1066,14 @@ void gx_process_cmdline_options(int& argc, char**& argv, string* optvar)
 		}
 	}
 
+	// *** process style_dir
+	if (!style_dir.empty()) {
+		gx_style_dir = style_dir;
+		if (gx_style_dir[gx_style_dir.size()-1] != '/') {
+			gx_style_dir += "/";
+		}
+	}
+
 	// *** process jack input
 	if (!jack_input.empty()) {
 		optvar[JACK_INP] = jack_input;
@@ -1076,7 +1108,7 @@ void gx_process_cmdline_options(int& argc, char**& argv, string* optvar)
 
 	optvar[LOAD_FILE] = load_file;
 
-	rcpath = GX_STYLE_DIR + string("/") + string("guitarix_") + optvar[RC_STYLE] + ".rc";
+	rcpath = gx_style_dir + string("guitarix_") + optvar[RC_STYLE] + ".rc";
 }
 
 void gx_set_override_options(string* optvar)
@@ -1242,6 +1274,15 @@ bool gx_version_check()
 		cim = string("echo 'guitarix-") + string(GX_VERSION) + "' >";
 		(void)gx_system_call(cim.c_str(), tmpstr.c_str(), false);
 
+        // create empty preset file
+        tmpstr = gx_user_dir + string("guitarixpre_rc");
+        ofstream nfile(tmpstr.c_str());
+        JsonWriter jw(nfile);
+        jw.begin_array();
+        writeHeader(jw);
+        jw.end_array(true);
+        jw.close();
+        nfile.close();
 
 	}
 
@@ -1285,9 +1326,8 @@ void gx_IntToString(int i, string & s)
 {
 	s = "";
 
-	int abs_i = abs(double(i));
-	do
-	{
+	int abs_i = abs(i);
+	do {
 		// note: using base 10 since 10 digits (0123456789)
 		char c = static_cast<char>(ASCII_START+abs_i%10);
 		s.insert(0, &c, 1);
@@ -1406,10 +1446,6 @@ void gx_destroy_event()
 		}
 	}
 
-	GtkRegler::gtk_regler_destroy();
-
-	gx_waveview_destroy(GTK_WIDGET(gx_gui::livewa), NULL);
-
 	gtk_main_quit();
 }
 
