@@ -36,22 +36,22 @@ class AudioVariables
 {
 public:
 	GxMidiState midistate;
-	int fnoise_g;
-	int fng;
+	bool fnoise_g;
+	bool fng;
 	float fnglevel;
-	int fcheckbox1;
-	int fupsample;
-	int antialis0;
-	int ftube;
-	int ftube3;
-	int fprdr;
-	int fconvolve;
+	bool fcheckbox1;
+	bool fupsample;
+	bool antialis0;
+	bool ftube;
+	bool ftube3;
+	bool fprdr;
+	bool fconvolve;
 	float convolvefilter;
-	int fresoon;
+	bool fresoon;
 	float posit0;
-	int fcheckbox5;
+	bool fcheckbox5;
 	float fautowah;
-	int fcheckboxcom1;
+	bool fcheckboxcom1;
 	float posit1;
 	float posit2;
 	float posit3;
@@ -61,24 +61,24 @@ public:
 	float posit7;
 	float posit8;
 	float posit9;
-	int foverdrive4;
-	int fcheckbox4;
-	int fcheckbox6;
+	bool foverdrive4;
+	bool fcheckbox4;
+	bool fcheckbox6;
 	int fcheckbox7;
-	int fcheckbox8;
+	bool fcheckbox8;
 	int fdelay;
-	int fmultifilter;
-	int fboost;
+	bool fmultifilter;
+	bool fboost;
 	int fchorus;
 	float ffuse;
-	float fdialogbox1;
-	float fdialogbox2;
-	float fdialogbox3;
-	float fdialogbox4;
+	bool fdialogbox1;
+	bool fdialogbox2;
+	bool fdialogbox3;
+	bool fdialogbox4;
 //float fdialogbox5;
-	float fdialogbox6;
-	float fdialogbox8;
-	float fdialogboxj;
+	bool fdialogbox6;
+	bool fdialogbox8;
+	bool fdialogboxj;
 	float fexpand;
 	float fexpand2;
 	float fwarn;
@@ -86,34 +86,43 @@ public:
 	float fskin;
 	float viv;
 	float vivi;
-	float fchorusbox;
+	bool fchorusbox;
 	float filebutton;
 	float fConsta1t;
 	float midistat;
-	int feq;
-	float fdialogbox_eq;
-	float fdialogbox_eqs;
-	float fdialogbox_mbf;
-	float fdialogbox_moo;
-	int fmoog;
-	int fflanger;
-	float fflangerbox;
-	int fbiquad;
-	float fbiquadbox;
-	int ftube3e;
+	bool feq;
+	bool fdialogbox_eq;
+	bool fdialogbox_eqs;
+	bool fdialogbox_mbf;
+	bool fdialogbox_moo;
+	bool fmoog;
+	bool fflanger;
+	bool fflangerbox;
+	bool fbiquad;
+	bool fbiquadbox;
+	bool ftube3e;
 	float upsample_mode;
 	float fampexpand;
 	int fsloop;
 	float witchdistortion;
-	float fdis1;
-	int fcab;
-	float fdialogbox_echo;
-	float fdialogbox_delay;
+	bool fdis1;
+	bool fcab;
+	bool fdialogbox_echo;
+	bool fdialogbox_delay;
 	float witcheq;
 	float witchamp;
-	int famp2;
+	bool famp2;
+	int tonestack;
+	int crybabypp;
+	int overdrivepp;
+	int distortionpp;
+	int freeverbpp;
+	int IRpp;
+	int compressorpp;
+	int echopp;
+	int delaypp;
 
-	AudioVariables();
+	void register_parameter();
 };
 
 extern AudioVariables audio;
@@ -157,7 +166,7 @@ public:
 	float fpitch;
 	int   noten;
 	float fslider32;
-	int fcheckbox10;
+	bool fcheckbox10;
 	int   program1;
 	int   send1;
 	int   noten1;
@@ -168,7 +177,7 @@ public:
 	int   noten2;
 	float fpitch1;
 	float fpitch2;
-	int fcheckbox11;
+	bool fcheckbox11;
 	int   program2;
 	int   volume2;
 	int Beat_is;
@@ -178,7 +187,7 @@ public:
 	float BeatFilter2;
 	float BeatFilterk;
 
-	MidiVariables();
+	void register_parameter();
 	void init(int samplingFreq);
 };
 
@@ -198,6 +207,7 @@ inline void turnOffMidi() { audio.midistate = kMidiOff; }
 inline void turnOnMidi() { audio.midistate = kMidiOn; }
 
 /* function declarations  */
+void register_faust_parameters();
 void gx_engine_init( const string *optvar );
 void gx_engine_reset();
 void faust_init(int samplingFreq);
